@@ -1,15 +1,15 @@
-# Copyright (c) 2009-2015 by Martin Becker.  All rights reserved.
+# Copyright (c) 2009-2016 by Martin Becker.  All rights reserved.
 # This package is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 #
-# $Id: Generic.pm 123 2015-04-18 20:22:56Z demetri $
+# $Id: Generic.pm 126 2016-07-28 13:10:20Z demetri $
 
 package Math::Polynomial::Generic;
 
 use 5.006;
 use strict;
 use warnings;
-use Carp qw(croak);
+use Carp qw(carp croak);
 use Math::Polynomial 1.000;
 
 require Exporter;
@@ -19,17 +19,35 @@ use base qw(Math::Polynomial Exporter);
 our @EXPORT_OK = qw( X C );
 our %EXPORT_TAGS = ( legacy => [] );
 
-our $VERSION = '1.008';
+our $VERSION = '1.009';
 
+my $deprecated  = 1;
 my $x_singleton = Math::Polynomial::Generic->new(0, 1);
 
-sub X () { return $x_singleton; }
+sub X () {
+    _warn_deprecated() if $deprecated;
+    return $x_singleton;
+}
 
 sub C ($) {
     my ($value) = @_;
     return Math::Polynomial->new($value);
 }
 
+sub import {
+    $deprecated = 1;
+    foreach my $arg (@_[1 .. $#_]) {
+        $deprecated = 0, last if ':legacy' eq $arg;
+    }
+    _warn_deprecated() if $deprecated;
+    Math::Polynomial::Generic->export_to_level(1, @_);
+}
+
+sub _warn_deprecated {
+    $deprecated = 0;
+    carp __PACKAGE__, ' is deprecated';
+}
+
 sub _is_generic { return 1; }
 
 sub _cast {
@@ -71,7 +89,7 @@ Math::Polynomial::Generic - syntactical sugar coating Math::Polynomial
 
 =head1 VERSION
 
-This documentation refers to version 1.008 of Math::Polynomial::Generic.
+This documentation refers to version 1.009 of Math::Polynomial::Generic.
 
 =head1 DEPRECATION NOTICE
 
@@ -84,16 +102,14 @@ This experiment is now considered a failure.  Coefficient spaces need to
 be specified at one point, and delaying this part of proper initialization
 seems do do more harm than good in terms of clarity.
 
-Therefore, Math::Polynomial::Generic is now scheduled for deprecation.
-Starting with the first version after January 1, 2016, using the
-module will trigger a deprecation warning unless the special symbol
-C<:legacy> appears on the import list.  At some later time, the
-module will be discontinued altogether.  Currently, importing
-C<:legacy> is optional and does nothing.
+Therefore, Math::Polynomial::Generic is now deprecated.  Using the module
+now triggers a deprecation warning unless the special symbol C<:legacy>
+appears on the import list.  At some time after January 1, 2017, the
+module will be discontinued altogether.
 
 =head1 SYNOPSIS
 
-  use Math::Polynomial::Generic qw(X C);
+  use Math::Polynomial::Generic qw(:legacy X C);
 
   $p = X**2 - 3 * X + 5;
   $q = $p * X;
@@ -183,7 +199,7 @@ polynomial object, add a C<C()>-wrapped zero value.
 =item I<mod>
 
 Currently, division of generic objects by generic objects (like C<X/X>) is
-not implemented.  The methods I<divmod>, I<div> and I<mod> are overriden
+not implemented.  The methods I<divmod>, I<div> and I<mod> are overridden
 to guard against such cases.
 
 =back
@@ -208,13 +224,24 @@ object C<$p>, the result sharing the coefficient space with C<$q>.
 By default, nothing is exported into the caller's namespace.  The
 polynomial generators X and C can be explicitly imported, however.
 
-The special symbol C<:legacy> can be imported without any consequences.
-In future versions of the library, it can be used to suppress
+The special symbol C<:legacy> can be imported in order to suppress
 deprecation warnings.
 
+=head2 DIAGNOSTICS
+
+=over 4
+
+=item Math::Polynomial::Generic is deprecated
+
+This warning is issued when the module is imported without the C<:legacy>
+tag in the import list or when Math::Polynomial::Generic::X is called
+for the first time after the module has been loaded without an import.
+
+=back
+
 =head2 MIGRATION
 
-As this module is scheduled for deprecation, existing applications
+As this module has been declared deprecated, existing applications
 should be migrated to no longer use it.  This, fortunately, is
 rather easy.  Instead of the symbol C<X>, we recommend to use a
 variable C<$X> that is initialized as
@@ -234,7 +261,7 @@ Martin Becker, E<lt>becker-cpan-mp@cozap.comE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009-2015 by Martin Becker.  All rights reserved.
+Copyright (c) 2009-2016 by Martin Becker.  All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.6 or,
